==> defend-the-castle-1.3.1.tgz: package/itemsAllText.js <==

const name0 = ctx._`Void`
const desc0 = ctx._`I don't know what that does...`
	
const name1 = ctx._`Bomb`
const desc1 = ctx._`Great damage! Perfect trap for enemy troop. But the shields can suffer damage.`
	
const name2 = ctx._`Zone War`
const desc2 = ctx._`Military will protect this area with their lives!`
	
const name3 = ctx._`Zone Defense`
const desc3 = ctx._`Military will protect this area with their lives!`
	
const name4 = ctx._`Rocket`
const desc4 = ctx._`Troop focused on knocking down drones and airplanes.`
	
const name5 = ctx._`Bank`
const desc5 = ctx._`Generate money for the castle.`
	
const name6 = ctx._`Tower Defense`
const desc6 = ctx._`Specialist in strategist of attack`
	
const name7 = ctx._`Hospital`
const desc7 = ctx._`Increases a health.`
	
const name10 = ctx._`Clone`
const desc10 = ctx._`2x Attack, Shield and Life & +350xp`
	
const name11 = ctx._`Diamond`
const desc11 = ctx._`Diamond!`
	
const name12 = ctx._`Super Shield`
const desc12 = ctx._`3x +Shield & +150 Xp`
	
const name13 = ctx._`Syringe`
const desc13 = ctx._`2x +Shield & 2x +Life`
	
const name14 = ctx._`Troops`
const desc14 = ctx._`+5 Troops`
	
const name15 = ctx._`Presents`
const desc15 = ctx._`+1 Present`
	
const namewins = ctx._`Detonated`
const descwins = ctx._`The Strongest!`
	
const namelosts = ctx._`Newbies`
const desclosts = ctx._`Everyone starts from somewhere, but where you start doesn't have to be where you end`
	
const namebattles = ctx._`Warriors`
const descbattles = ctx._`Living from fights!`
	
const namemoney = ctx._`Master`
const descmoney = ctx._`Money is no problem 😜`
	
const namelevel = ctx._`Mr.Future`
const desclevel = ctx._`Also known as leaders`
	
const nameadmins = ctx._`Admins/Developer`
const descadmins = ctx._`Game Creators`
	
const namemods = ctx._`Moderators`
const descmods = ctx._`Game Moderators`
	
const nameonline = ctx._`Fan`
const desconline = ctx._`Fans of Defend The Castle`
	
const textbadges = ctx._`Be the King of Emblems`
	
const textpresent = ctx._`🎁 Find the best present!`
	
const textfight = ctx._`Show your power to the other castles 🤔😉`
	
const textkey = ctx._`Find the key (🔑) to the Castle vault.`
	
const textpoints = ctx._`Earn points for your clan.`
	
const namewarrior = ctx._`Warrior`
const descwarrior = ctx._`Perfect for Fights!`
	
const namebanker = ctx._`Banker`
const descbanker = ctx._`Money move the world!`
	
const nameadventurer = ctx._`Adventurer`
const descadventurer = ctx._`Everyone seeks something!`

==> defend-the-castle-1.3.3.tgz: package/itemsAllText.js <==

const name0 = ctx._`Void`
const desc0 = ctx._`I don't know what that does...`
	
const name1 = ctx._`Bomb`
const desc1 = ctx._`Great damage! Perfect trap for enemy troop. But the shields can suffer damage.`
	
const name2 = ctx._`Zone War`
const desc2 = ctx._`Military will protect this area with their lives!`
	
const name3 = ctx._`Zone Defense`
const desc3 = ctx._`Military will protect this area with their lives!`
	
const name4 = ctx._`Rocket`
const desc4 = ctx._`Troop focused on knocking down drones and airplanes.`
	
const name5 = ctx._`Bank`
const desc5 = ctx._`Generate money for the castle.`
	
const name6 = ctx._`Tower Defense`
const desc6 = ctx._`Specialist in strategist of attack`
	
const name7 = ctx._`Hospital`
const desc7 = ctx._`Increases a health.`
	
const name10 = ctx._`Clone`
const desc10 = ctx._`2x Attack, Shield and Life & +350xp`
	
const name11 = ctx._`Diamond`
const desc11 = ctx._`Diamond!`
	
const name12 = ctx._`Super Shield`
const desc12 = ctx._`3x +Shield & +150 Xp`
	
const name13 = ctx._`Syringe`
const desc13 = ctx._`2x +Shield & 2x +Life`
	
const name14 = ctx._`Troops`
const desc14 = ctx._`+5 Troops`
	
const name15 = ctx._`Presents`
const desc15 = ctx._`+1 Present`
	
const namewins = ctx._`Detonated`
const descwins = ctx._`The Strongest!`
	
const namelosts = ctx._`Newbies`
const desclosts = ctx._`Everyone starts from somewhere, but where you start doesn't have to be where you end`
	
const namebattles = ctx._`Warriors`
const descbattles = ctx._`Living from fights!`
	
const namemoney = ctx._`Master`
const descmoney = ctx._`Money is no problem 😜`
	
const namelevel = ctx._`Mr.Future`
const desclevel = ctx._`Also known as leaders`
	
const nameadmins = ctx._`Admins/Developer`
const descadmins = ctx._`Game Creators`
	
const namemods = ctx._`Moderators`
const descmods = ctx._`Game Moderators`
	
const nameonline = ctx._`Fan`
const desconline = ctx._`Fans of Defend The Castle`
	
const textbadges = ctx._`Be the King of Emblems`
	
const textpresent = ctx._`🎁 Find the best present!`
	
const textfight = ctx._`Show your power to the other castles 🤔😉 (+15 Batles)`
	
const textfightSuper = ctx._`Show your power to the other castles 🤔😉 (+200 Batles)`
	
const textkey = ctx._`Find the key (🔑) to the Castle vault.`
	
const textpoints = ctx._`Earn points for your clan.`
	
const textupgrade = ctx._`Upgrade a building with +20 levels (instantly).`
	
const textconsecutiveBattles = ctx._`Win +30 consecutive battles.`
	
const namewarrior = ctx._`Warrior`
const descwarrior = ctx._`Perfect for Fights!`
	
const namebanker = ctx._`Banker`
const descbanker = ctx._`Money move the world!`
	
const nameadventurer = ctx._`Adventurer`
const descadventurer = ctx._`Everyone seeks something!`
